pub struct PendingWorkState {
pub has_pending: bool,
}Expand description
Whether the run has outstanding work that should prevent NaturalEnd.
Plugins write true when they have pending work (e.g. background tasks).
The orchestrator reads this at NaturalEnd to decide whether to terminate
or enter a waiting state.
Fields
has_pending: boolTrait Implementations
Sourceimpl Clone for PendingWorkState
impl Clone for PendingWorkState
Sourcefn clone(&self) -> PendingWorkState
fn clone(&self) -> PendingWorkState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PendingWorkState
impl Debug for PendingWorkState
Sourceimpl Default for PendingWorkState
impl Default for PendingWorkState
Sourcefn default() -> PendingWorkState
fn default() -> PendingWorkState
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PendingWorkState
impl<'de> Deserialize<'de> for PendingWorkState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PendingWorkState
impl PartialEq for PendingWorkState
Sourceimpl Serialize for PendingWorkState
impl Serialize for PendingWorkState
impl Eq for PendingWorkState
impl StructuralPartialEq for PendingWorkState