pub struct ToolCallState {
pub call_id: String,
pub tool_name: String,
pub arguments: Value,
pub status: ToolCallStatus,
pub updated_at: u64,
pub resume_mode: ToolCallResumeMode,
pub suspension_id: Option<String>,
pub suspension_reason: Option<String>,
pub resume_input: Option<ToolCallResume>,
}Expand description
Per-tool-call lifecycle state.
Fields
call_id: Stringtool_name: Stringarguments: Valuestatus: ToolCallStatusupdated_at: u64resume_mode: ToolCallResumeModeResume mode from the SuspendTicket (set when status becomes Suspended).
suspension_id: Option<String>External-facing suspension id used by protocols that distinguish approval/interrupt ids from the underlying tool call id.
suspension_reason: Option<String>Suspension reason/action from the active SuspendTicket.
resume_input: Option<ToolCallResume>Most recent external resume input applied to this suspended tool call.
Implementations
Sourceimpl ToolCallState
impl ToolCallState
pub fn new( call_id: impl Into<String>, tool_name: impl Into<String>, arguments: Value, status: ToolCallStatus, updated_at: u64, ) -> Self
pub fn with_resume_mode(self, resume_mode: ToolCallResumeMode) -> Self
pub fn with_suspension( self, suspension_id: Option<String>, suspension_reason: Option<String>, ) -> Self
pub fn with_resume_input(self, resume_input: Option<ToolCallResume>) -> Self