BackgroundTaskPlugin

Struct BackgroundTaskPlugin 

pub struct BackgroundTaskPlugin { /* private fields */ }
Plugin that registers the background task view state key and the persisted task metadata state key.

Implementations

Source

impl BackgroundTaskPlugin

pub fn new(manager: Arc<BackgroundTaskManager>) -> Self

pub fn with_store( manager: Arc<BackgroundTaskManager>, store: StateStore, ) -> Self

Create the plugin and wire the store into the manager.

pub fn manager(&self) -> &Arc<BackgroundTaskManager>

Return the manager for inbox wiring.