StateCommand

Struct StateCommand 

pub struct StateCommand {
    pub patch: MutationBatch,
    pub scheduled_actions: Vec<ScheduledAction>,
    pub effects: Vec<TypedEffect>,
}
A command that carries state mutations, scheduled actions, and effects.

This is the primary mechanism for both plugin hooks and tools to express side-effects. Plugins return StateCommand from phase hooks; tools return it alongside ToolResult to declare their side-effects using the same machinery.

Fields

patch: MutationBatchscheduled_actions: Vec<ScheduledAction>effects: Vec<TypedEffect>

Implementations

Source

impl StateCommand

pub fn new() -> StateCommand

pub fn with_base_revision(self, revision: u64) -> StateCommand

pub fn is_empty(&self) -> bool

pub fn scheduled_actions(&self) -> &[ScheduledAction]

Inspect scheduled actions (useful for testing).

pub fn emit<E>( &mut self, payload: <E as EffectSpec>::Payload, ) -> Result<(), StateError>
where E: EffectSpec,

pub fn schedule_action<A>( &mut self, payload: <A as ScheduledActionSpec>::Payload, ) -> Result<(), StateError>

pub fn extend(&mut self, other: StateCommand) -> Result<(), StateError>

pub fn merge_parallel<F>( self, other: StateCommand, strategy: F, ) -> Result<StateCommand, StateError>
where F: Fn(&str) -> MergeStrategy,

Merge two commands from parallel execution using the given merge strategy.

Methods from Deref<Target = MutationBatch>

pub fn base_revision(&self) -> Option<u64>

pub fn is_empty(&self) -> bool

pub fn update<K>(&mut self, update: <K as StateKey>::Update)
where K: StateKey,

pub fn clear_extension_with( &mut self, key: impl Into<String>, clear: fn(&mut StateMap), )

pub fn extend(&mut self, other: MutationBatch) -> Result<(), StateError>

pub fn op_len(&self) -> usize