pub struct BackgroundTaskPlugin { /* private fields */ }Expand description
Plugin that registers the background task view state key and the persisted task metadata state key.
Implementations
Sourceimpl BackgroundTaskPlugin
impl BackgroundTaskPlugin
pub fn new(manager: Arc<BackgroundTaskManager>) -> Self
Sourcepub fn with_store(
manager: Arc<BackgroundTaskManager>,
store: StateStore,
) -> Self
pub fn with_store( manager: Arc<BackgroundTaskManager>, store: StateStore, ) -> Self
Create the plugin and wire the store into the manager.
Sourcepub fn manager(&self) -> &Arc<BackgroundTaskManager>
pub fn manager(&self) -> &Arc<BackgroundTaskManager>
Return the manager for inbox wiring.